@@ -80,7 +80,7 @@
   {%- set target_relation = api.Relation.create(database=database, schema=schema, identifier=identifier,
                                                type='table') -%}
   {%- set agate_table = load_agate_table() -%}
-  {%- do store_result('agate_table', status='OK', agate_table=agate_table) -%}
+  {%- do store_result('agate_table', response='OK', agate_table=agate_table) -%}
 
   {{ run_hooks(pre_hooks, inside_transaction=False) }}
 
